@@ -1,7 +1,9 @@
 import nomad.api.exceptions
 
+from nomad.api.base import Requester
 
-class Namespaces(object):
+
+class Namespaces(Requester):
 
     """
     The namespaces from enterprise solution
@@ -10,8 +12,8 @@ class Namespaces(object):
     """
     ENDPOINT = "namespaces"
 
-    def __init__(self, requester):
-        self._requester = requester
+    def __init__(self, **kwargs):
+        super(Namespaces, self).__init__(**kwargs)
 
     def __str__(self):
         return "{0}".format(self.__dict__)
@@ -25,10 +27,10 @@ class Namespaces(object):
 
     def __contains__(self, item):
         try:
-            namespaces = self._get()
+            namespaces = self.get_namespaces()
 
-            for j in namespaces:
-                if j["Name"] == item:
+            for n in namespaces:
+                if n["Name"] == item:
                     return True
             else:
                 return False
@@ -36,31 +38,25 @@ class Namespaces(object):
             return False
 
     def __len__(self):
-        namespaces = self._get()
+        namespaces = self.get_namespaces()
         return len(namespaces)
 
     def __getitem__(self, item):
         try:
-            namespaces = self._get()
+            namespaces = self.get_namespaces()
 
-            for j in namespaces:
-                if j["Name"] == item:
-                    return j
+            for n in namespaces:
+                if n["Name"] == item:
+                    return n
             else:
                 raise KeyError
         except nomad.api.exceptions.URLNotFoundNomadException:
             raise KeyError
 
     def __iter__(self):
-        namespaces = self._get()
+        namespaces = self.get_namespaces()
         return iter(namespaces)
 
-    def _get(self, *args):
-        url = self._requester._endpointBuilder(Namespaces.ENDPOINT, *args)
-        namespaces = self._requester.get(url)
-
-        return namespaces.json()
-
     def get_namespaces(self):
         """ Lists all the namespaces registered with Nomad.
 
@@ -71,4 +67,4 @@ class Namespaces(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._get()
+        return self.request(method="get").json()
