@@ -1,7 +1,9 @@
 import nomad.api.exceptions
 
+from nomad.api.base import Requester
 
-class Node(object):
+
+class Node(Requester):
 
     """
     The node endpoint is used to query the a specific client node.
@@ -11,8 +13,8 @@ class Node(object):
     """
     ENDPOINT = "node"
 
-    def __init__(self, requester):
-        self._requester = requester
+    def __init__(self, **kwargs):
+        super(Node, self).__init__(**kwargs)
 
     def __str__(self):
         return "{0}".format(self.__dict__)
@@ -27,7 +29,7 @@ class Node(object):
     def __contains__(self, item):
 
         try:
-            n = self._get(item)
+            n = self.get_node(item)
             return True
         except nomad.api.exceptions.URLNotFoundNomadException:
             return False
@@ -35,7 +37,7 @@ class Node(object):
     def __getitem__(self, item):
 
         try:
-            n = self._get(item)
+            n = self.get_node(item)
 
             if n["ID"] == item:
                 return n
@@ -46,12 +48,6 @@ class Node(object):
         except nomad.api.exceptions.URLNotFoundNomadException:
             raise KeyError
 
-    def _get(self, *args):
-        url = self._requester._endpointBuilder(Node.ENDPOINT, *args)
-        node = self._requester.get(url)
-
-        return node.json()
-
     def get_node(self, id):
         """ Query the status of a client node registered with Nomad.
 
@@ -62,7 +58,7 @@ class Node(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._get(id)
+        return self.request(id, method="get").json()
 
     def get_allocations(self, id):
         """ Query the allocations belonging to a single node.
@@ -74,17 +70,7 @@ class Node(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._get(id, "allocations")
-
-    def _post(self, *args, **kwargs):
-        url = self._requester._endpointBuilder(Node.ENDPOINT, *args)
-
-        if kwargs:
-            response = self._requester.post(url, params=kwargs.get("enable", None), json=kwargs.get("payload", {}))
-        else:
-            response = self._requester.post(url)
-
-        return response.json()
+        return self.request(id, "allocations", method="get").json()
 
     def evaluate_node(self, id):
         """ Creates a new evaluation for the given node.
@@ -98,7 +84,7 @@ class Node(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._post(id, "evaluate")
+        return self.request(id, "evaluate", method="post").json()
 
     def drain_node(self, id, enable=False):
         """ Toggle the drain mode of the node.
@@ -116,7 +102,7 @@ class Node(object):
               - nomad.api.exceptions.URLNotFoundNomadException
         """
 
-        return self._post(id, "drain", enable={"enable": enable})
+        return self.request(id, "drain", params={"enable": enable}, method="post").json()
 
     def drain_node_with_spec(self, id, drain_spec, mark_eligible=None):
         """ This endpoint toggles the drain mode of the node. When draining is enabled,
@@ -161,7 +147,7 @@ class Node(object):
                 "DrainSpec": None,
             }
 
-        return self._post(id, "drain", payload=payload)
+        return self.request(id, "drain", json=payload, method="post").json()
 
     def eligible_node(self, id, eligible=None, ineligible=None):
         """ Toggle the eligibility of the node.
@@ -193,7 +179,7 @@ class Node(object):
         elif ineligible is not None and not ineligible:
             payload = {"Eligibility": "eligible", "NodeID": id}
 
-        return self._post(id, "eligibility", payload=payload)
+        return self.request(id, "eligibility", json=payload, method="post").json()
 
     def purge_node(self, id):
         """ This endpoint purges a node from the system. Nodes can still join the cluster if they are alive.
@@ -205,5 +191,5 @@ class Node(object):
           - nomad.api.exceptions.URLNotFoundNomadException
         """
 
-        return self._post(id, "purge")
+        return self.request(id, "purge", method="post").json()
 
