@@ -1,7 +1,7 @@
-import nomad.api.exceptions
+from nomad.api.base import Requester
 
 
-class Sentinel(object):
+class Sentinel(Requester):
 
     """
     The endpoint manage sentinel policies (Enterprise Only)
@@ -11,8 +11,8 @@ class Sentinel(object):
 
     ENDPOINT = "sentinel"
 
-    def __init__(self, requester):
-        self._requester = requester
+    def __init__(self, **kwargs):
+        super(Sentinel, self).__init__(**kwargs)
 
     def __str__(self):
         return "{0}".format(self.__dict__)
@@ -23,33 +23,6 @@ class Sentinel(object):
     def __getattr__(self, item):
         raise AttributeError
 
-    def _get(self, *args, **kwargs):
-        url = self._requester._endpointBuilder(Sentinel.ENDPOINT, *args)
-        response = self._requester.get(url,
-                                       params=kwargs.get("params", None))
-
-        return response.json()
-
-    def _post(self, *args, **kwargs):
-        url = self._requester._endpointBuilder(Sentinel.ENDPOINT, *args)
-
-        if kwargs:
-            response = self._requester.post(url, json=kwargs.get("json_dict", None), params=kwargs.get("params", None))
-        else:
-            response = self._requester.post(url)
-
-        return response.json()
-
-    def _post_no_json(self, *args, **kwargs):
-        url = self._requester._endpointBuilder(Sentinel.ENDPOINT, *args)
-            
-        if kwargs:
-            response = self._requester.post(url, json=kwargs.get("json_dict", None), params=kwargs.get("params", None))
-        else:
-            response = self._requester.post(url)
-
-        return response
-
     def get_policies(self):
         """ Get a list of policies.
 
@@ -61,7 +34,7 @@ class Sentinel(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._get("policies")
+        return self.request("policies", method="get").json()
 
     def create_policy(self, id, policy):
         """ Create policy.
@@ -70,14 +43,13 @@ class Sentinel(object):
 
             arguments:
                 - policy
-            returns: dict
+            returns: requests.Response
 
             raises:
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._post_no_json("policy", id, json_dict=policy)
-
+        return self.request("policy", id, json=policy, method="post")
 
     def get_policy(self, id):
         """ Get a spacific policy.
@@ -90,7 +62,7 @@ class Sentinel(object):
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._get("policy", id)
+        return self.request("policy", id, method="get").json()
 
     def update_policy(self, id, policy):
         """ Create policy.
@@ -100,13 +72,13 @@ class Sentinel(object):
             arguments:
                 - name
                 - policy
-            returns: dict
+            returns: requests.Response
 
             raises:
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._post_no_json("policy", id, json_dict=policy)
+        return self.request("policy", id, json=policy, method="post")
 
     def delete_policy(self, id):
         """ Delete specific policy.
@@ -115,16 +87,10 @@ class Sentinel(object):
 
             arguments:
                 - id
+            returns: Boolean
 
             raises:
               - nomad.api.exceptions.BaseNomadException
               - nomad.api.exceptions.URLNotFoundNomadException
         """
-        return self._delete("policy", id)
-
-    def _delete(self, *args, **kwargs):
-        url = self._requester._endpointBuilder(Sentinel.ENDPOINT, *args)
-        response = self._requester.delete(url,
-                                          params=kwargs.get("params", None))
-
-        return response.ok
+        return self.request("policy", id, method="delete").ok
